@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
+
 import sys
 import signal
 from os import environ
@@ -74,7 +74,7 @@ try:
     def sigint_handler(*args):
         pass
 
-    class ClMessageBox(object):
+    class ClMessageBox():
         """
         ProgressDialog in other process
         """
