@@ -14,13 +14,13 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
+
 from .utils.text import convertStrListDict
-from calculate.lib.configparser import ConfigParser
+from .configparser import ConfigParser
 from collections import defaultdict
 
 
-class convertEnv(object):
+class convertEnv():
     """Конвертирование переменных из /var/calculate/remote/calculate.env"""
     envPath = "/var/calculate/remote/calculate.env"
     convertData = {
