@@ -14,14 +14,14 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
+
 import sys
 import os
 import hashlib
 import crypt
 import string
 from random import choice
-from base64 import encodestring as _b64enc
+from base64 import encodebytes as _b64enc
 
 b64encode = lambda x: _b64enc(x).rstrip()
 try:
@@ -32,7 +32,7 @@ from .cl_print import color_print
 from . import cl_overriding
 from calculate.contrib.passlib.hash import sha256_crypt, grub_pbkdf2_sha512
 
-from calculate.lib.cl_lang import setLocalTranslate
+from .cl_lang import setLocalTranslate
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
