@@ -16,10 +16,10 @@
 
 import sys
 import re
-from calculate.lib.cl_template import TemplateFormat
-from calculate.lib.utils.files import process
+from ..cl_template import TemplateFormat
+from ..utils.files import process
 
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
