@@ -15,26 +15,27 @@
 #  limitations under the License.
 
 import sys
-from calculate.lib.cl_xml import xpath
-from calculate.lib.format.xml_gconf import xml_gconf
-from calculate.lib.cl_lang import setLocalTranslate
-from collections import Iterable
+from ..cl_xml import xpath
+from .xml_gconf import xml_gconf
+from ..cl_lang import setLocalTranslate
+from collections.abc import Iterable
+from copy import deepcopy
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
-
+#TODO probably very buggy due to xpath
 class xml_gconf_tree(xml_gconf):
     """Класс для объединения gconf_tree-xml файлов"""
 
     def _join(self, xmlNewNode, xmlOldNode, flagRootNode=True, **kw):
         """Объединение корневой ноды шаблона и корневой ноды файла"""
         xmlNode = xmlNewNode
-        childNodes = xmlNode.childNodes
+        childNodes = list(xmlNode)
         nextOldNode = xmlOldNode
         if xmlNode.nodeType == xmlNode.ELEMENT_NODE:
             n = xmlNode
-            tagName = n.tagName
+            tagName = n.tag
             tagNameStr = tagName.encode("UTF-8")
             nAction = u''
             attrName = ''
@@ -48,15 +49,15 @@ class xml_gconf_tree(xml_gconf):
                     self.setError(_("The text is not a valid gconf-XML format \
 (found '<%(tag)s>..</%(tag)s>')") % {'tag': tagNameStr})
                     return False
-                if not n.hasAttribute("name"):
+                if "name" not in n.keys():
                     self.setError(
                         _('Not found attribute "name" in %(tag)s')
                         % {'tag': tagNameStr})
                     return False
-                nName = n.getAttribute("name")
+                nName = n.get("name")
                 attrName = u"attribute::name='%s'" % nName
-            if n.hasAttribute("action"):
-                nAction = n.getAttribute("action")
+            if "action" in n.keys():
+                nAction = n.get("action")
                 if nAction not in ("join", "replace", "drop"):
                     textError = _("In the text of the XML template, "
                                   "reserved attribute 'action' comes with an "
@@ -66,14 +67,14 @@ class xml_gconf_tree(xml_gconf):
                                   'action="drop")')
                     self.setError(textError)
                     return False
-            if xmlOldNode.parentNode:
+            if xmlOldNode.getparent() is not None:
                 findAttrStr = ""
                 if attrName:
                     findAttrStr = "[%s]" % attrName
                 findPath = u"child::%s%s" % (tagName, findAttrStr)
                 # Рабочая нода
                 if flagRootNode:
-                    workNode = xmlOldNode.parentNode
+                    workNode = xmlOldNode.getparent()
                 else:
                     workNode = xmlOldNode
                 oldNodes = xpath.Evaluate(findPath, workNode)
@@ -102,67 +103,63 @@ class xml_gconf_tree(xml_gconf):
                     nextOldNode = oldNodes[0]
                     # Объединение аттрибутов нод
                     if flagJoin:
-                        listOldAttributes = nextOldNode.attributes.items()
+                        listOldAttributes = list(nextOldNode.attrib.items())
                         if listOldAttributes:
-                            listOldAttributes = filter(
-                                lambda x: x[0] != "mtime", listOldAttributes)
+                            listOldAttributes = [x for x 
+                                in listOldAttributes if x[0] != "mtime"]
                         # Замена содержимого
-                        if xmlNode.tagName == "entry":
-                            replaceXmlNode = xmlNode.cloneNode(True)
+                        if xmlNode.tag == "entry":
+                            replaceXmlNode = deepcopy(xmlNode)
                             # Сравнение содержимого нод
                             if not self.cmpListsNodesEntry([replaceXmlNode],
                                                            [nextOldNode]):
-                                replaceXmlNode.setAttribute("mtime",
-                                                            self.currentTime)
+                                replaceXmlNode.set("mtime", self.currentTime)
                                 if not self._removeDropNodesAndAttrAction(
                                         replaceXmlNode):
                                     return False
-                                workNode.replaceChild(replaceXmlNode,
-                                                      nextOldNode)
+                                workNode.replace(nextOldNode, replaceXmlNode)
                             childNodes = False
-                        listNewAttributes = xmlNode.attributes.items()
+                        listNewAttributes = xmlNode.attrib.items()
                         if listNewAttributes:
-                            listNewAttributes = filter(
-                                lambda x: x[0] not in ("action", "mtime"),
-                                listNewAttributes)
+                            listNewAttributes = [x for x 
+                                in listNewAttributes if x[0] not in ("action", "mtime")]
                         if set(listNewAttributes) != set(listOldAttributes):
                             # Объединение аттрибутов
                             for attrName, attrValue in listNewAttributes:
-                                nextOldNode.setAttribute(attrName, attrValue)
-                            if nextOldNode.tagName == "entry":
-                                nextOldNode.setAttribute("mtime",
+                                nextOldNode.set(attrName, attrValue)
+                            if nextOldNode.tag == "entry":
+                                nextOldNode.set("mtime",
                                                          self.currentTime)
                     # Замещение ноды
                     elif flagReplace:
-                        replaceXmlNode = xmlNode.cloneNode(True)
+                        replaceXmlNode = deepcopy(xmlNode)
                         # Сравнение содержимого нод
                         if not self.cmpListsNodesEntry([replaceXmlNode],
                                                        [nextOldNode]):
-                            if replaceXmlNode.tagName == "entry":
-                                replaceXmlNode.setAttribute("mtime",
+                            if replaceXmlNode.tag == "entry":
+                                replaceXmlNode.set("mtime",
                                                             self.currentTime)
                             if not self._removeDropNodesAndAttrAction(
                                     replaceXmlNode):
                                 return False
-                            workNode.replaceChild(replaceXmlNode,
-                                                  nextOldNode)
+                            workNode.replace(nextOldNode, replaceXmlNode)
                         childNodes = False
                     # Удаление ноды
                     elif flagDrop:
-                        workNode.removeChild(nextOldNode)
+                        workNode.remove(nextOldNode)
                         childNodes = False
                 else:
                     # Добавление ноды
                     childNodes = False
                     if not flagDrop:
-                        appendXmlNode = xmlNode.cloneNode(True)
-                        if appendXmlNode.tagName == "entry":
-                            appendXmlNode.setAttribute("mtime",
+                        appendXmlNode = deepcopy(xmlNode)
+                        if appendXmlNode.tag == "entry":
+                            appendXmlNode.set("mtime",
                                                        self.currentTime)
                         if not self._removeDropNodesAndAttrAction(
                                 appendXmlNode):
                             return False
-                        workNode.appendChild(appendXmlNode)
+                        workNode.append(appendXmlNode)
             if isinstance(childNodes, Iterable):
                 for node in childNodes:
                     if not self._join(node, nextOldNode, False):
