@@ -14,14 +14,14 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
-from xml.etree import ElementTree as ET
+# from xml.etree import ElementTree as ET
+from lxml import etree as ET
 from .palette import (TextState, BaseColorMapping,
                      ConsoleCodeMapping, LightColorMapping, ConsoleColor256,
                      ConsoleCodesInfo, SpanPalette, XmlFormat)
 
 
-class BaseOutput(object):
+class BaseOutput():
     """
     Базовый вывод текста.
 
@@ -154,7 +154,7 @@ class SaveAttrOutput(BaseOutput):
     """
 
     def __init__(self, state=None):
-        super(SaveAttrOutput, self).__init__()
+        super().__init__()
         self.prev_state = state.clone() if state else TextState()
         self.current_state = self.prev_state.clone()
         self.state_stack = []
@@ -237,11 +237,11 @@ class ColorTerminalOutput(SaveAttrOutput):
 
     def setBold(self):
         self.resetHalfbright()
-        super(ColorTerminalOutput, self).setBold()
+        super().setBold()
 
     def setHalfbright(self):
         self.resetBold()
-        super(ColorTerminalOutput, self).setHalfbright()
+        super().setHalfbright()
 
     def handleForeground(self, prevstate, curstate, attrs, tail_attrs):
         """Обработать изменение тона"""
@@ -327,7 +327,7 @@ class ColorTerminalOutput(SaveAttrOutput):
         """
         Создать ESC строку
         """
-        attrs = map(str, ['%s[' % self.escSymb] + attrs + ['m'])
+        attrs = [str(x) for x in ['%s[' % self.escSymb] + attrs + ['m']]
         return "%s%s%s" % (attrs[0], ";".join(attrs[1:-1]), attrs[-1])
 
     def outputText(self, s):
@@ -375,8 +375,7 @@ class ColorTerminal256Output(ColorTerminalOutput):
                           ConsoleCodesInfo.COLOR256,
                           color256])
         else:
-            super(ColorTerminal256Output,
-                  self).handleForeground(prevstate, curstate, attrs, tail_attrs)
+            super().handleForeground(prevstate, curstate, attrs, tail_attrs)
 
     def handleBackground(self, prevstate, curstate, attrs, tail_attrs):
         color = curstate.background
@@ -388,8 +387,7 @@ class ColorTerminal256Output(ColorTerminalOutput):
                           ConsoleCodesInfo.COLOR256,
                           color256])
         else:
-            super(ColorTerminal256Output,
-                  self).handleBackground(prevstate, curstate, attrs, tail_attrs)
+            super().handleBackground(prevstate, curstate, attrs, tail_attrs)
 
 
 class ColorTerminal16Output(ColorTerminalOutput):
@@ -420,7 +418,7 @@ class ColorTerminal16Output(ColorTerminalOutput):
         _curstate = curstate.clone()
         _curstate.foreground = \
             self._handleNearestColors(curstate.foreground)
-        super(ColorTerminal16Output, self).handleForeground(
+        super().handleForeground(
             prevstate, _curstate,
             attrs, tail_attrs)
 
@@ -436,7 +434,7 @@ class ColorTerminal16Output(ColorTerminalOutput):
         # преобразовать яркий цвет к обычному
         _curstate.background = \
             mapHighNormal.get(_curstate.background, _curstate.background)
-        super(ColorTerminal16Output, self).handleBackground(
+        super().handleBackground(
             prevstate, _curstate,
             attrs, tail_attrs)
 
@@ -529,7 +527,7 @@ class XmlOutput(SaveAttrOutput):
     escaper = XmlFormat.escaper
 
     def __init__(self, state=None):
-        super(XmlOutput, self).__init__(state=state)
+        super().__init__(state=state)
         self.clear_state = TextState()
 
     def getXML(self, curstate, text):
@@ -562,7 +560,8 @@ class XmlOutput(SaveAttrOutput):
         if curstate.bold:
             tail = ET.SubElement(tail, Tags.BOLD)
         tail.text = text
-        return root[0]
+        # return root[0]
+        return root
 
     def xmlToString(self, xml):
         """
@@ -575,16 +574,19 @@ class XmlOutput(SaveAttrOutput):
                                    " ".join(['%s="%s"' % (k, v) for k, v in
                                              root.attrib.items()]))
             else:
-                yield "<%s>" % root.tag
+                #py3 compat :(
+                if root.tag != "root":
+                    yield "<%s>" % root.tag
             if len(root):
                 for element in root:
                     for text in generator(element):
                         yield text
             if root.text:
                 yield self.escaper(root.text)
-            yield "</%s>" % root.tag
+            if root.tag != "root":
+                yield "</%s>" % root.tag
 
-        return "".join(filter(None, list(generator(xml))))
+        return "".join((x for x in generator(xml) if x))
 
     def outputText(self, s):
         if self.clear_state != self.current_state:
@@ -603,7 +605,7 @@ class XmlOutput(SaveAttrOutput):
         return "<tab/>"
 
 
-class BasePositionOutput(object):
+class BasePositionOutput():
     """
     Объект составляющий ESC последовательности для управлением местом вывода
     """
@@ -656,7 +658,7 @@ class TerminalPositionOutput(BasePositionOutput):
     Управление позицией вывода текста в терминале
     """
 
-    class Codes(object):
+    class Codes():
         UP = 'A'
         DOWN = 'B'
         RIGHT = 'C'
