@@ -17,10 +17,10 @@
 import re
 from itertools import chain
 from math import pow
-from calculate.lib.utils.text import MultiReplace
+from ..text import MultiReplace
 
 
-class ConsoleCodesInfo(object):
+class ConsoleCodesInfo():
     """
     Коды цветов
     """
@@ -49,7 +49,7 @@ def getColorMatch(colorList):
     return [colorList[x] + (colorList[x + 1] - colorList[x]) // 2
                   for x in range(0, 5)] + [255]
 
-class ConsoleColor256(object):
+class ConsoleColor256():
     """Объект перевода RGB цветов в консоль 256color"""
     colorList = (0, 95, 135, 175, 215, 255)
     colorMatch = getColorMatch(colorList)
@@ -128,7 +128,7 @@ def bitProperty(bit):
 
     return property(get, set)
 
-class TextState(object):
+class TextState():
     """
     Параметры текста
 
@@ -142,14 +142,14 @@ class TextState(object):
     False
     """
 
-    class Attributes(object):
+    class Attributes():
         NONE = 0
         BOLD = 1
         HALFBRIGHT = 2
         UNDERLINE = 4
         INVERT = 8
 
-    class Colors(object):
+    class Colors():
         # обычные цвета
         BLACK = "black"
         RED = "red"
@@ -210,14 +210,22 @@ class TextState(object):
 
     def __cmp__(self, other):
         for i in ["foreground", "background", "attr"]:
-            cmp_res = cmp(getattr(self, i), getattr(other, i))
+            cmp_res = getattr(self, i) > getattr(other, i) - (getattr(self, i) < getattr(other, i))
             if cmp_res:
                 return cmp_res
         return 0
 
+    def __lt__(self, other):
+        for i in ["foreground", "background", "attr"]:
+            cmp_res = getattr(self, i) > getattr(other, i) - (getattr(self, i) < getattr(other, i))
+            if cmp_res:
+                return cmp_res
+        return 0
+
+
     @classmethod
     def colors(cls):
-        return chain(xrange(0, 8), [None])
+        return chain(range(0, 8), [None])
 
 
 class BaseColorMapping:
@@ -444,12 +452,12 @@ class GuiPalette(SpanPalette):
                           ["#303030", "#c6403d", "#3dc640", "#c3c63d",
                            "#403dc6", "#c63dc3", "#3dc3c6", "#ffffff"]))
 
-class XmlFormat(object):
+class XmlFormat():
     """
     Константы для внутреннего формата XML
     """
 
-    class Tags(object):
+    class Tags():
         BOLD = "b"
         UNDERLINE = "u"
         FONT = "font"
@@ -458,7 +466,7 @@ class XmlFormat(object):
         NEWLINE = "br"
         TAB = "tab"
 
-    class FontAttributes(object):
+    class FontAttributes():
         BACKGROUND = "bgColor"
         FOREGROUND = "color"
 
