@@ -13,6 +13,7 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+
 import hashlib
 import select
 import random
@@ -30,16 +31,17 @@ import re
 import sys
 from itertools import *
 import tarfile
-import tools
+from . import tools
 import fcntl
-from tools import ignore
+from .tools import ignore
 from glob import glob
 
 from contextlib import contextmanager
 import signal
+from functools import reduce
 
 _ = lambda x: x
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
@@ -80,20 +82,18 @@ except ImportError as e:
         MAGIC_MIME_TYPE = 0x010
         MAGIC_MIME_ENCODING = 0x400
 
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
-reSearch = lambda pattern, listar: map(lambda x: x.groups(),
-                                       filter(None,
-                                              map(pattern.search, listar)))
+reSearch = lambda pattern, listar: [x.groups() for x in map(pattern.search, listar) if x]
 
 
 class FilesError(Exception):
     pass
 
 
-class StdoutableProcess(object):
+class StdoutableProcess():
     def __init__(self):
         self.pipe = None
 
@@ -150,7 +150,7 @@ class process(StdoutableProcess):
     PIPE = PIPE
 
     def __init__(self, command, *params, **kwarg):
-        super(process, self).__init__()
+        super().__init__()
         if "stdin" not in kwarg:
             stdin = PipeProcess()
         else:
@@ -201,7 +201,7 @@ class process(StdoutableProcess):
         """Write to process stdin"""
         self._open()
         try:
-            self.pipe.stdin.write(data)
+            self.pipe.stdin.write(data if isinstance(data, bytes) else data.encode("UTF-8"))
             self.pipe.stdin.flush()
         except IOError as e:
             raise FilesError(str(e))
@@ -223,7 +223,7 @@ class process(StdoutableProcess):
             try:
                 self.cacheerr = self.pipe.stderr.read()
             except IOError:
-                self.cacheerr = ""
+                self.cacheerr = b""
         return self.cacheerr
 
     def readByLine(self):
@@ -269,8 +269,8 @@ class process(StdoutableProcess):
             raise KeyboardInterrupt
         finally:
             if self.cacheresult is None:
-                self.cacheresult = "\n".join(self._cachedata)
-            self.cacheerr = "".join(_cacheerr)
+                self.cacheresult = b'\n'.join(self._cachedata)
+            self.cacheerr = b''.join(_cacheerr)
             self.close()
 
     def read(self):
@@ -283,7 +283,7 @@ class process(StdoutableProcess):
                 else:
                     for line in self.readByLine():
                         pass
-            return self.cacheresult
+            return self.cacheresult.decode(encoding="UTF-8")
         except KeyboardInterrupt:
             self.kill()
             raise KeyboardInterrupt
@@ -307,7 +307,7 @@ class process(StdoutableProcess):
 
     def next(self):
         """Next string from stdout"""
-        return self.__iter__().next()
+        return next(self.__iter__())
 
     def returncode(self):
         """Get return code"""
@@ -357,28 +357,28 @@ def chown(fn, uid=None, gid=None):
         os.lchown(fn, uid, gid)
 
 
-class FilePermission(object):
+class FilePermission():
     """
     Права на файл
     """
-    UserWrite = 0200
-    UserRead = 0400
-    UserExecute = 0100
+    UserWrite = 0o200
+    UserRead = 0o400
+    UserExecute = 0o100
     UserAll = UserWrite | UserRead | UserExecute
 
-    GroupWrite = 020
-    GroupRead = 040
-    GroupExecute = 010
+    GroupWrite = 0o20
+    GroupRead = 0o40
+    GroupExecute = 0o10
     GroupAll = GroupWrite | GroupRead | GroupExecute
 
-    OtherWrite = 02
-    OtherRead = 04
-    OtherExecute = 01
+    OtherWrite = 0o2
+    OtherRead = 0o4
+    OtherExecute = 0o1
     OtherAll = OtherWrite | OtherRead | OtherExecute
 
-    SetUid = 04000
-    SetGid = 02000
-    StickyBit = 01000
+    SetUid = 0o4000
+    SetGid = 0o2000
+    StickyBit = 0o1000
 
 
 def chmod(fn, mode):
@@ -439,9 +439,8 @@ class UnixUtilityFile:
                      MAGIC_MIME_TYPE: "--mime-type",
                      MAGIC_MIME_ENCODING: "--mime-encoding",
                      MAGIC_COMPRESS: "-z"}
-        appendParam = map(lambda x: paramdict[x],
-                          filter(lambda x: flags & x,
-                                 sorted(paramdict.keys())))
+        appendParam = [paramdict[x] for x 
+            in sorted(paramdict.keys()) if flags & x]
         fileCmd = getProgPath('/usr/bin/file')
         return [fileCmd, '-b'] + appendParam
 
@@ -468,7 +467,7 @@ class UnixUtilityFile:
                 pass
         return None
 
-class typeFile(object):
+class typeFile():
     """Получение типа файла"""
 
     def __init__(self, magic=MAGIC_MIME_ENCODING | MAGIC_MIME_TYPE):
@@ -554,7 +553,7 @@ class typeFile(object):
         """является ли файл бинарным"""
         mime = self.getMType(filename)
         if mime:
-            if mime.startswith("text"):
+            if mime.startswith('text'):
                 return False
             else:
                 return True
@@ -634,9 +633,10 @@ class processProgress(process):
             raise
         finally:
             if self._cachedata:
-                self.cacheresult = "\n".join(self._cachedata)
+                self.cacheresult = b"\n".join((x if isinstance(x, bytes) 
+                    else x.encode("UTF-8") for x in self._cachedata))
             else:
-                self.cacheresult = ""
+                self.cacheresult = b""
 
 
 def countFiles(dirpath, onefilesystem=True):
@@ -647,8 +647,7 @@ def countFiles(dirpath, onefilesystem=True):
     for dirpath, dirnames, filenames in os.walk(dirpath):
         num += len(set(dirnames) | set(filenames))
         if onefilesystem:
-            mountDirs = filter(lambda x: path.ismount(path.join(dirpath, x)),
-                               dirnames)
+            mountDirs = (x for x in dirnames if path.ismount(path.join(dirpath, x)))
             for dirname in mountDirs:
                 dirnames.remove(dirname)
     return num
@@ -699,7 +698,7 @@ def check_rw(dn):
     """
     def _random_string(l=10):
         return "".join(
-            random.choice(string.ascii_letters) for i in xrange(0, l))
+            random.choice(string.ascii_letters) for i in range(0, l))
 
     mark_file = None
     while mark_file is None or path.exists(mark_file):
@@ -744,29 +743,27 @@ def pathJoin(*paths):
     """Складывает пути, в отличии от os.path.join, складывает абсолютные пути"""
     if len(paths) == 1:
         return paths[0]
-    return reduce(path.join,
-                  filter(lambda x: x and x != "/",
-                         map(lambda x: x.startswith("/") and x[1:] or x,
-                             paths[1:])), paths[0])
+    return reduce(path.join, (x for x 
+        in (y.startswith("/") and y[1:] or y for y 
+        in paths[1:]) if x and x != "/"), paths[0])
 
 
 def listDirectory(directory, fullPath=False, onlyDir=False):
     """Get files from directory, if it exists"""
+    #just to make sure:
+    if isinstance(directory, bytes):
+        directory = directory.decode("UTF-8")
     if not path.exists(directory):
         return []
     try:
         if fullPath:
             if onlyDir:
-                return filter(lambda x: path.isdir(x),
-                              map(lambda x: path.join(directory, x),
-                                  os.listdir(directory)))
+                return [x for x in [path.join(directory, z) for z in os.listdir(directory)] if path.isdir(x)]
             else:
-                return map(lambda x: path.join(directory, x),
-                           os.listdir(directory))
+                return [path.join(directory, x) for x in os.listdir(directory)]
         else:
             if onlyDir:
-                return filter(lambda x: path.isdir(path.join(directory, x)),
-                              os.listdir(directory))
+                return [x for x in os.listdir(directory) if path.isdir(path.join(directory, x))]
             else:
                 return os.listdir(directory)
     except OSError:
@@ -800,7 +797,7 @@ def readLinesFile(filename, grab=False):
     """Read file by line"""
     try:
         if path.exists(filename):
-            for line in open(filename, 'r'):
+            for line in open(filename, 'r', encoding='utf-8'):
                 if grab:
                     line = line.strip()
                     if not line.startswith("#"):
@@ -809,8 +806,9 @@ def readLinesFile(filename, grab=False):
                     yield line.rstrip('\n')
     except (OSError, IOError):
         pass
-    finally:
-        raise StopIteration
+    # at least in python3, yield should give StopIteration automatically
+    # finally:
+    #     raise StopIteration
 
 
 def isEmptyFile(filename, grab=False):
@@ -827,20 +825,24 @@ def grepFile(filename, regexp, flags=0):
         return match.group()
     return ""
 
-def readFile(filename):
+def readFile(filename, encoding='utf-8', binary=False):
     """
     Прочитать целый файл или вернуть пустую строку в случае ошибки
     """
     try:
         if path.exists(filename):
-            with open(filename, 'r') as f:
-                return f.read()
+            mode = 'rb' if binary else 'r'
+            encoding = None if binary else encoding
+            with open(filename, mode, encoding=encoding) as f:
+                tmp = f.read()
+                return tmp
     except (OSError, IOError) as e:
         mod, lno = tools.get_traceback_caller(*sys.exc_info())
         sys.stderr.write("WARNING: file read error, {}({}:{})\n".format(
             str(e), mod, lno))
         sys.stderr.flush()
-    return ""
+    return "" if not binary else b""
+
 
 def readFileEx(filename, tailbyte=None, headbyte=None, grab=False):
     """
@@ -851,11 +853,11 @@ def readFileEx(filename, tailbyte=None, headbyte=None, grab=False):
     """
     try:
         if path.exists(filename):
-            with open(filename, 'r') as f:
+            with open(filename, 'rb') as f:
                 if grab:
-                    filterfunc = lambda s: "\n".join(
-                        x for x in s.split("\n")
-                        if not x.startswith("#") and x.strip())
+                    filterfunc = lambda s: b"\n".join(
+                        x for x in s.split(b"\n")
+                        if not x.startswith(b"#") and x.strip())
                 else:
                     filterfunc = lambda x: x
                 if tailbyte:
@@ -871,20 +873,21 @@ def readFileEx(filename, tailbyte=None, headbyte=None, grab=False):
         sys.stderr.write("WARNING: file read error, {}({}:{})\n".format(
             str(e), mod, lno))
         sys.stderr.flush()
-    return ""
+    return b""
 
 
-def writeFile(filename):
+def writeFile(filename, encoding='utf-8', binary=False):
     """
     Открыть файл на запись и создать необходимые каталоги
     """
     dn = path.dirname(filename)
     if not path.exists(dn):
         os.makedirs(dn)
-    return open(filename, 'w')
+    mode = 'wb' if binary else 'w'
+    encoding = None if binary else encoding
+    return open(filename, mode, encoding=encoding)
 
-
-class GetProgPath(object):
+class GetProgPath():
     """Get full path of program or False"""
     cache = {}
 
@@ -939,10 +942,8 @@ def getCmdLineParam(paramName):
     """
     cmdLine = '/proc/cmdline'
     paramName = "%s=" % paramName
-    params = \
-        map(lambda x: x.partition('=')[2],
-            filter(lambda x: x.startswith(paramName),
-                   readFile(cmdLine).split(' ')))
+    params = [x.partition('=')[2] for x 
+        in readFile(cmdLine).split(' ') if x.startswith(paramName)]
     if params:
         return params[-1]
     else:
@@ -961,11 +962,10 @@ def tarLinks(rootpath, archpath, skip=()):
     tar = tarfile.open(archpath, "w:bz2")
     # find links
     if skip:
-        reSkip = re.compile("|".join(map(lambda x: x.replace("*", ".*"),
-                                         skip))).search
+        reSkip = re.compile("|".join((x.replace("*", ".*") for x in skip))).search
     else:
         reSkip = lambda x: False
-    for link in ifilterfalse(reSkip,
+    for link in filterfalse(reSkip,
                              find(rootpath, filetype=FindFileType.SymbolicLink,
                                   onefilesystem=True)):
         ti = tar.gettarinfo(link)
@@ -995,7 +995,7 @@ def getch():
         return ""
 
 
-class FindFileType(object):
+class FindFileType():
     """
     Типы файлов для find
     """
@@ -1116,10 +1116,8 @@ def getLoopFromPath(directory):
     losetup = getProgPath('losetup')
     p = process(losetup, '-a')
     rePattern = re.compile('(^/dev/loop[^:]+)[^(]+\(([^)]+)\).*')
-    return map(lambda x: x[0],
-               filter(lambda x: x[1].startswith(directory),
-                      reSearch(rePattern,
-                               p.readlines())))
+    return [x[0] for x in reSearch(rePattern, p.readlines()) 
+        if x[1].startswith(directory)]
 
 
 def getMdRaidDevices():
@@ -1127,9 +1125,8 @@ def getMdRaidDevices():
     Получить словарь: какой mdraid какие использует устройства
     """
     reMdInfo = re.compile('^(\w+)\s+:\s+active.*?raid\d+\s+(.*)')
-    return dict(map(lambda x: (x[0], map(lambda x: x.partition('[')[0],
-                                         x[1].split())),
-                    reSearch(reMdInfo, readLinesFile('/proc/mdstat'))))
+    return dict(((x[0], [y.partition('[')[0] for y in x[1].split()]) for x 
+        in reSearch(reMdInfo, readLinesFile('/proc/mdstat'))))
 
 
 class PercentProgress(processProgress):
@@ -1138,7 +1135,7 @@ class PercentProgress(processProgress):
     
     Args:
         part: количество прогрессов в программе
-        delimeter: разделители строк по умолчанию \n и \r
+        delimeter: разделители строк по умолчанию \\n и \\r
         cachefilter: фильтр вывода программы (регулярная строка)
         startpart: используется для вывода процентов прогрессбар
                    с определенного места (0 по умолчанию)
@@ -1156,6 +1153,7 @@ class PercentProgress(processProgress):
         self.is_end = kwargs.get("end", True)
         self.stderr = STDOUT
         self.delimeter = re.compile("[%s]" % kwargs.get("delimeter", "\n\r"))
+        #TODO do something with this monster?
         self.cachedata = re.compile(kwargs.get("cachefilter",
                                                "((?:\[31;01m\*|\[33;01m\*|"
                                                "Bad Option|No space left|FATAL ERROR|SYNTAX:|mkisofs:|"
@@ -1238,7 +1236,7 @@ def get_active_tty():
     return None
 
 
-class scanDirectory(object):
+class scanDirectory():
     """Класс для cканирования директории"""
 
     def processingFile(self, pathname, prefix):
@@ -1439,7 +1437,7 @@ def tar_unpack(archfile, target_dn):
         raise FilesError(_("Failed to create tarball: %s") % str(e))
 
 
-class RsyncOptions(object):
+class RsyncOptions():
     Xattrs = "--xattrs"
     KeepDirLinks = "--keep-dirlinks"
     OneFileSystem = "--one-file-system"
@@ -1492,7 +1490,7 @@ def xz(data, decompress=False):
     else:
         raise FilesError(errors)
 
-class XZStreamRead(object):
+class XZStreamRead():
     """
     XZ объект для чтения данных для tarfile
     """
@@ -1536,7 +1534,7 @@ def sha256sum(*fns):
     kb = 1024
     hasher = sha256()
     for fn in fns:
-        with open(fn) as f:
+        with open(fn, "rb") as f:
             b = True
             while b:
                 b = f.read(512 * kb)
@@ -1578,7 +1576,7 @@ def move_files(source, target):
 class RCSError(Exception):
     pass
 
-class DirectoryRCS(object):
+class DirectoryRCS():
     """
     Объект оперирует тремя каталогами, в котором хранит:
     фиксированную версию данных
@@ -1696,7 +1694,7 @@ def checkDigestFile(digestfile):
             hashobj = getattr(hashlib, alg.lower())
             filename = path.join(path.dirname(digestfile), filename)
             if os.path.exists(filename):
-                with open(filename, 'r') as f:
+                with open(filename, 'r', encoding='utf-8') as f:
                     digest = hashobj(f.read())
                 result.append((alg,
                                digest.hexdigest().upper() == hashdata.upper()))
@@ -1758,20 +1756,14 @@ def getRunCommands(not_chroot=False, chroot=None, uid=None, withpid=False,
     if not os.access('/proc', os.R_OK):
         return []
     if withpid:
-        return filter(lambda x: x[1],
-                      map(lambda x:(x,getCmd(x)),
-                          filter(lambda x: x.isdigit(),
-                                 listDirectory('/proc'))))
+        return [x for x in [(y, getCmd(y)) for y in listDirectory('/proc') if y.isdigit()] if x[1]]
     else:
-        return filter(None,
-                      map(getCmd,
-                          filter(lambda x: x.isdigit(),
-                                 listDirectory('/proc'))))
+        return [x for x in [getCmd(y) for y in listDirectory('/proc') if y.isdigit()] if x]
 
 class XAttrError(Exception):
     pass
 
-class xattr(object):
+class xattr():
     getfattr = '/bin/getfattr'
     setfattr = '/bin/setfattr'
 
@@ -1781,11 +1773,11 @@ class xattr(object):
         if p.success():
             return p.read()
         err = p.readerr()
-        raise XAttrError(err.partition(":")[2].strip())
+        raise XAttrError(err.partition(b":")[2].strip())
 
     @classmethod
     def set(cls, dn, attrname, value):
         p = process(cls.setfattr, "-n", attrname, "-v", value, dn)
         if not p.success():
             err = p.readerr()
-            raise XAttrError(err.rpartition(":")[2].strip())
+            raise XAttrError(err.rpartition(b":")[2].strip())
