@@ -18,17 +18,17 @@ import re
 import sys
 import os
 from os import path
-from calculate.lib.configparser import ConfigParser
+from ..configparser import ConfigParser
 import shutil
 
-from calculate.lib.utils.files import (getProgPath, STDOUT,
+from .files import (getProgPath, STDOUT,
                                        PercentProgress, process, readFile,
                                        writeFile, listDirectory, removeDir)
-from calculate.lib.utils.tools import AddonError
-from calculate.lib.utils.ip import check_port
+from .tools import AddonError
+from .ip import check_port
 
 _ = lambda x: x
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
@@ -41,7 +41,7 @@ class NotGitError(GitError):
     """Данная директория не является Git"""
 
 
-class Git(object):
+class Git():
     """
     Объект для управление git репозиторием
     """
@@ -363,7 +363,7 @@ class Git(object):
             return True
         return False
 
-    class Reference(object):
+    class Reference():
         Branch = "branch"
         Tag = "tag"
         # RemoteBranch = "remote_branch"
@@ -481,7 +481,7 @@ class Git(object):
             return fetch_info['type']
         return self.Reference.Unknown
 
-    class GitProtocol(object):
+    class GitProtocol():
         SSH = 22
         Git = 9418
         HTTP = 80
@@ -856,7 +856,7 @@ class Git(object):
         return True
 
 
-class MTimeKeeper(object):
+class MTimeKeeper():
     """
     Сохранить и восстановить mtime на файлы
     """
