@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
+
 from .files import (process, checkUtils, readFile, listDirectory,
                    getRunCommands, getProgPath, FilesError)
 from . import device
@@ -30,7 +30,7 @@ from os import path
 import select
 import time
 
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
@@ -98,10 +98,9 @@ def checkNet(net):
     return (strIpToIntIp(ip) & mask) == (strIpToIntIp(ip))
 
 
-maskDigs = map(lambda x: str(x),
-               (0b10000000, 0b11000000, 0b11100000, 0b11110000,
-                0b11111000, 0b11111100, 0b11111110, 0b11111111))
-
+maskDigs = [str(x) for x 
+    in (0b10000000, 0b11000000, 0b11100000, 0b11110000,
+        0b11111000, 0b11111100, 0b11111110, 0b11111111)]
 
 def checkMask(mask):
     """Check net"""
@@ -177,14 +176,11 @@ def getIpNet(ip, mask=None, cidr=None):
 
 def isIpInNet(checkip, *ipnets):
     """Check is ip in specified nets"""
-    return map(lambda x: x[0],
-               filter(lambda x: strIpToIntIp(checkip) & x[2] == strIpToIntIp(
-                   x[1]) & x[2],
-                      map(lambda x: (
-                          x[0], x[1][0],
-                          strIpToIntIp(cidrToMask(int(x[1][1])))),
-                          map(lambda x: (x, x.partition('/')[0::2]),
-                              ipnets))))
+    return [x[0] for x 
+        in [(y[0], y[1][0], strIpToIntIp(cidrToMask(int(y[1][1])))) for y 
+            in [(z, z.partition('/')[0::2]) for z 
+                in ipnets]] 
+        if strIpToIntIp(checkip) & x[2] == strIpToIntIp(x[1]) & x[2]]
 
 def isUsingNetworkManager():
     try:
@@ -207,19 +203,16 @@ def isDhcpIp(interface="eth0"):
         return True
     commands = getRunCommands()
     dhcpProgs = ("dhcpcd", "dhclient", "udhcpc")
-    if filter(lambda x: interface in x and any(prog in x for prog in dhcpProgs),
-              commands):
+    if [x for x in commands if interface in x and any(prog in x for prog in dhcpProgs)]:
         return True
     else:
         # если запущен демон dhcpcd
-        if filter(lambda x: "dhcpcd\x00-q" in x, commands):
+        if [x for x in commands if "dhcpcd\x00-q" in x]:
             curIp = getIp(interface)
             dhcpcd = getProgPath('/sbin/dhcpcd')
-            leaseIp = \
-                map(lambda x: x.group(1),
-                    filter(None,
-                           map(re.compile('^ip_address=(.*)$').search,
-                               process(dhcpcd, '-U', interface))))
+            leaseIp = [x.group(1) for x 
+                in map(re.compile('^ip_address=(.*)$').search, 
+                    process(dhcpcd, '-U', interface)) if x]
             if not curIp or leaseIp and leaseIp[0] == curIp:
                 return True
         return False
@@ -230,11 +223,11 @@ def getRouteTable(onlyIface=()):
     ipProg = checkUtils('/sbin/ip')
     routes = process(ipProg, "route")
     if onlyIface:
-        filterRe = re.compile("|".join(map(lambda x: r"dev %s" % x, onlyIface)))
+        filterRe = re.compile("|".join(("dev %s" % x for x in onlyIface)))
         routes = filter(filterRe.search, routes)
     for line in routes:
         network, op, line = line.partition(" ")
-        routeParams = map(lambda x: x.strip(), line.split())
+        routeParams = [x.strip() for x in line.split()]
         # (network,{'via':value,'dev':value})
         if network:
             yield (network, dict(zip(routeParams[0::2], routeParams[1::2])))
@@ -280,7 +273,7 @@ def getMaster(iface):
 
 def getIp(iface):
     sockfd = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    ifreq = struct.pack('16sH14s', iface, socket.AF_INET, '\x00' * 14)
+    ifreq = struct.pack('16sH14s', iface.encode("UTF-8"), socket.AF_INET, b'\x00' * 14)
     try:
         res = fcntl.ioctl(sockfd, SIOCGIFADDR, ifreq)
     except IOError:
@@ -292,7 +285,7 @@ def getIp(iface):
 
 def checkFlag(iface, flag):
     sockfd = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    ifreq = struct.pack('16sH14s', iface, socket.AF_INET, '\x00' * 14)
+    ifreq = struct.pack('16sH14s', iface.encode("UTF-8"), socket.AF_INET, b'\x00' * 14)
     try:
         res = fcntl.ioctl(sockfd, SIOCGIFFLAGS, ifreq)
     except IOError:
@@ -315,7 +308,7 @@ def getMask(iface):
     Get mask for interface
     """
     sockfd = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    ifreq = struct.pack('16sH14s', iface, socket.AF_INET, '\x00' * 14)
+    ifreq = struct.pack('16sH14s', iface.encode("UTF-8"), socket.AF_INET, b'\x00' * 14)
     try:
         res = fcntl.ioctl(sockfd, SIOCGIFNETMASK, ifreq)
     except IOError:
@@ -336,7 +329,7 @@ def getMac(iface):
     Get mac for interface
     """
     sockfd = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    ifreq = struct.pack('16sH14s', iface, socket.AF_UNIX, '\x00' * 14)
+    ifreq = struct.pack('16sH14s', iface.encode("UTF-8"), socket.AF_UNIX, b'\x00' * 14)
     try:
         res = fcntl.ioctl(sockfd, SIOCGIFHWADDR, ifreq)
     except IOError:
@@ -374,7 +367,7 @@ class IPError(Exception):
     pass
 
 
-class Pinger(object):
+class Pinger():
     # ICMP parameters
     ICMP_ECHO = 8  # Echo request (per RFC792)
     ICMP_MAX_RECV = 2048  # Max size of incoming buffer
