@@ -14,20 +14,20 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
+
 import sys
 import re
 from os import path
 from .files import typeFile, process
 from subprocess import Popen, PIPE
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
 class InitrdFileError(Exception):
     pass
 
-class InitrdFile(object):
+class InitrdFile():
     """
     Работа с initrd файлом
     """
