@@ -15,13 +15,13 @@
 #  limitations under the License.
 import sys
 from abc import ABCMeta, abstractmethod
-from calculate.lib.utils.files import process, getProgPath
-from calculate.lib.utils.tools import Sizes, classificate, traverse
-from calculate.lib.utils.device import humanreadableSize
+from .files import process, getProgPath
+from .tools import Sizes, classificate, traverse
+from .device import humanreadableSize
 import re
 
 _ = lambda x: x
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
@@ -31,15 +31,13 @@ def round_disk_size(size):
 class VolumesError(Exception):
     pass
 
-class VolumesBuilder(object):
+class VolumesBuilder(metaclass=ABCMeta):
 
-    __metaclass__ = ABCMeta
-
-    class DeviceType(object):
+    class DeviceType():
         Device = 0
         RAID = 1
 
-    class VolumeType(object):
+    class VolumeType():
         Generic = 0
         Raid = 2
         Fat32 = 3
@@ -51,7 +49,7 @@ class VolumesBuilder(object):
         Lvm = 9
         Extended = 10
 
-    class Purpose(object):
+    class Purpose():
         Undefined = 100
         EfiBoot = 101
         BiosBoot = 102
@@ -104,8 +102,7 @@ class VolumesBuilder(object):
         pass
 
 
-class DosDisk(object):
-    __metaclass__ = ABCMeta
+class DosDisk(metaclass=ABCMeta):
 
     @abstractmethod
     def get_partition_name(self, num):
@@ -136,8 +133,7 @@ class DosDisk(object):
         pass
 
 
-class GptDisk(object):
-    __metaclass__ = ABCMeta
+class GptDisk(metaclass=ABCMeta):
 
     @abstractmethod
     def create_table(self):
@@ -160,8 +156,7 @@ class GptDisk(object):
         pass
 
 
-class LvmDisk(object):
-    __metaclass__ = ABCMeta
+class LvmDisk(metaclass=ABCMeta):
 
     @abstractmethod
     def create_lvm(self):
@@ -176,13 +171,13 @@ class LvmDisk(object):
         pass
 
 
-class BlockDisk(object):
+class BlockDisk():
     pass
 
 class VirtualDiskError(Exception):
     pass
 
-class SizeableDisk(object):
+class SizeableDisk():
     AllFree = None
     header_size = 0
 
@@ -223,7 +218,7 @@ class SizeableDisk(object):
 class VirtualDisk(SizeableDisk, DosDisk, GptDisk):
     parttype = ""
 
-    class Partition(object):
+    class Partition():
         def __init__(self, dev=None, mount=None, part=None,
                      partid=None, size=None):
             self.dev = dev
@@ -237,7 +232,7 @@ class VirtualDisk(SizeableDisk, DosDisk, GptDisk):
         self.parent = parent
         self.dev = dev
         self.partitions = []
-        super(VirtualDisk, self).__init__(size)
+        super().__init__(size)
 
     volume_types_map = {}
 
@@ -333,7 +328,7 @@ class VirtualDosDisk(VirtualDisk, DosDisk):
     header_size = Sizes().M
 
     def write(self):
-        res = super(VirtualDosDisk, self).write()
+        res = super().write()
         self.parent.set_mbr(self.dev)
         return res
 
@@ -343,7 +338,7 @@ class VirtualGptDisk(VirtualDisk, GptDisk):
 
 class VirtualLvm(SizeableDisk, LvmDisk):
 
-    class Volume(object):
+    class Volume():
         def __init__(self, dev=None, mount=None, size=None):
             self.dev = dev
             self.mount = mount
@@ -356,7 +351,7 @@ class VirtualLvm(SizeableDisk, LvmDisk):
         self.disk_size = vgsize
         self.vgname = vgname
         self.volumes = []
-        super(VirtualLvm, self).__init__(vgsize)
+        super().__init__(vgsize)
 
     volume_types_map = {}
 
@@ -408,11 +403,10 @@ class VirtualLvm(SizeableDisk, LvmDisk):
             self.parent.disk_format.append(partition.format)
 
 
-class Fdisk(SizeableDisk):
-    __metaclass__ = ABCMeta
+class Fdisk(SizeableDisk, metaclass=ABCMeta):
 
     def __init__(self, dev, disk_size):
-        super(Fdisk, self).__init__(disk_size)
+        super().__init__(disk_size)
         self.fdisk_process = process(self.fdisk_cmd, dev)
         self.fdisk = []
         self.dev = dev
@@ -452,7 +446,7 @@ class Fdisk(SizeableDisk):
                 self.fdisk.append("t\n%d\n%s\n" % (partnum, partid))
 
     def search_errors(self, errors):
-        return re.search("Value out of range[.]|: unknown command",
+        return re.search(rb"Value out of range[.]|: unknown command",
                          errors)
 
     def write(self):
@@ -521,7 +515,7 @@ class GptFdisk(Fdisk, GptDisk):
 class LvmVolumeGroup(SizeableDisk, LvmDisk):
 
     def __init__(self, devices, vgname, vgsize, extsize=None):
-        super(LvmVolumeGroup, self).__init__(vgsize)
+        super().__init__(vgsize)
         self.devices = devices
         self.vgname = vgname
         self.vgsize = vgsize
@@ -583,7 +577,7 @@ class LvmVolumeGroup(SizeableDisk, LvmDisk):
         pass
 
 
-class DosPartitionId(object):
+class DosPartitionId():
     volume_types_map = {
         VolumesBuilder.VolumeType.Ntfs: "07",
         VolumesBuilder.VolumeType.Extended: "05",
@@ -601,7 +595,7 @@ class DosPartitionId(object):
             _id, cls.volume_types_map[fallback])
 
 
-class GptPartitionId(object):
+class GptPartitionId():
     volume_types_map = {
         VolumesBuilder.VolumeType.Ntfs: "ebd0a0a2-b9e5-4433-87c0-68b6b72699c7",
         VolumesBuilder.VolumeType.Fat32: "ebd0a0a2-b9e5-4433-87c0-68b6b72699c7",
@@ -661,7 +655,7 @@ class RoundableVolumesBuilder(VolumesBuilder):
         self.minimal = size
 
 
-class LvmCalculator(object):
+class LvmCalculator():
     def __init__(self, parent):
         self.parent = parent
         self.size = 0
@@ -771,7 +765,7 @@ class GptBuilder(RoundableVolumesBuilder):
         if not self.gptdisk.write():
             raise VolumesError(_("Failed to create GPT partition table"))
 
-class GptRules(object):
+class GptRules():
     parent = None
 
     def finish(self):
@@ -819,7 +813,7 @@ def BiosBoot(obj, size=None):
 
 class GptPosBootRules(GptFirstBootRules):
     def __init__(self, boot_size, part_pos=4):
-        super(GptPosBootRules, self).__init__(boot_size)
+        super().__init__(boot_size)
         self.part_pos = part_pos
 
     def create_volume(self, size, purpose):
@@ -880,7 +874,7 @@ class LvmBuilder(RoundableVolumesBuilder):
         self.lvmdisk.write()
 
 
-class VolumesSet(object):
+class VolumesSet():
     def __init__(self, builder):
         self.builder = builder
         self.params = []
@@ -907,8 +901,7 @@ class VolumesSet(object):
         self.builder.finish()
 
 
-class BuilderFactory(object):
-    __metaclass__ = ABCMeta
+class BuilderFactory(metaclass=ABCMeta):
 
     @abstractmethod
     def createDosBuilder(self, device, size):
@@ -935,8 +928,7 @@ class DiskFactory(BuilderFactory):
                                          extsize=extsize))
 
 
-class DeviceInfo(object):
-    __metaclass__ = ABCMeta
+class DeviceInfo(metaclass=ABCMeta):
 
     @abstractmethod
     def get_device_type(self, path=None, name=None):
@@ -944,17 +936,17 @@ class DeviceInfo(object):
 
 class PurposedDosBuilder(DosBuilder):
     def change_purpose(self, purpose):
-        super(PurposedDosBuilder, self).change_purpose(purpose)
+        super().change_purpose(purpose)
         self.dosdisk.change_purpose(purpose)
 
 class PurposedGptBuilder(GptBuilder):
     def change_purpose(self, purpose):
-        super(PurposedGptBuilder, self).change_purpose(purpose)
+        super().change_purpose(purpose)
         self.gptdisk.change_purpose(purpose)
 
 class PurposedLvmBuilder(LvmBuilder):
     def change_purpose(self, purpose):
-        super(PurposedLvmBuilder, self).change_purpose(purpose)
+        super().change_purpose(purpose)
         self.lvmdisk.change_purpose(purpose)
 
 class VariableFactory(BuilderFactory):
@@ -1027,8 +1019,8 @@ class SchemeError(Exception):
 class DeviceSchemeError(SchemeError):
     pass
 
-class SchemeBuilder(object):
-    class PartitionTable(object):
+class SchemeBuilder():
+    class PartitionTable():
         GPT = 0
         DOS = 1
 
