@@ -23,9 +23,9 @@ import datetime
 import functools
 import bz2
 
-from calculate.lib.cl_xml import ET
+from ..cl_xml import ET
 import pexpect
-from calculate.lib.configparser import ConfigParser
+from ..configparser import ConfigParser
 
 from .colortext.palette import TextState
 from .common import cmpVersion
@@ -33,20 +33,22 @@ from .files import (getProgPath, find, process, listDirectory, readFile,
                     readLinesFile, pathJoin, makeDirectory,
                     FilesError, rsync_files, RsyncOptions,
                     removeDir, removeFileWithEmptyDirectory, FindFileType)
-from .tools import SavableIterator, ignore
+from .tools import SaveableIterator, ignore
 from .system import SystemPath
-from collections import Mapping, defaultdict
+from collections.abc import Mapping
+from collections import defaultdict
 from .common import getTupleVersion
 from contextlib import closing
 from functools import total_ordering
-from itertools import ifilter, imap, chain, groupby
+#no ifiller, imap in python3
+from itertools import chain, groupby
 import hashlib
 
 Colors = TextState.Colors
 import glob
 
 _ = lambda x: x
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
@@ -55,7 +57,7 @@ VDB_PATH = 'var/db/pkg'
 reVerSplit = re.compile(r"^(?:.*/%s/)?(?:(\w+-\w+)/)?(.*?)-(([^-]+?)"
                         "(?:-(r\d+))?)(?:.(tbz2))?$" % VDB_PATH, re.S)
 
-class RepositoryPath(object):
+class RepositoryPath():
     Layman = '/var/lib/layman'
     Repos = "/var/db/pkg"
     Calculate = path.join(Repos, "calculate")
@@ -66,7 +68,8 @@ class RepositoryPath(object):
 
 def reVerSplitToPV(x):
     """Convert match from reVerSplit to PV hash"""
-    if type(x) in (str, unicode):
+    # if type(x) in (str, unicode):
+    if isinstance(x, str):
         x = reVerSplit.search(x)
     if x:
         match = x.groups()
@@ -91,11 +94,10 @@ def getPkgUses(fullpkg, version=None, prefix="/"):
     _pkgCategory = '{0}/{1}'.format(VDB_PATH, category)
     pkgCategory = path.join(prefix, _pkgCategory)
     if version is None:
-        packages = filter(lambda x: x['PN'] == pkg,
-                          map(reVerSplitToPV,
-                              filter(lambda x: x,
-                                     map(lambda x: reVerSplit.search(x),
-                                         listDirectory(pkgCategory)))))
+        packages = [x for x 
+            in [reVerSplitToPV(y) for y 
+                in [reVerSplit.search(z) for z 
+                    in listDirectory(pkgCategory)] if y] if x['PN'] == pkg]
         if not packages:
             return None
         usePath = path.join(pkgCategory, packages[-1]['PF'], "USE")
@@ -105,12 +107,8 @@ def getPkgUses(fullpkg, version=None, prefix="/"):
         iusePath = path.join(pkgCategory, "%s-%s" % (pkg, version), "IUSE")
     iuse = readFile(iusePath).strip().split()
     use = readFile(usePath).strip().split()
-    return (map(lambda x: x[1:] if x.startswith("+") else x,
-                filter(lambda x: x,
-                       use)),
-            map(lambda x: x[1:] if x.startswith("+") else x,
-                filter(lambda x: x,
-                       iuse)))
+    return ([x[1:] if x.startswith("+") else x for x in use if x],
+        [x[1:] if x.startswith("+") else x for x in iuse if x])
 
 
 def isPkgInstalled(pkg, prefix='/', sortByVersion=False):
@@ -132,10 +130,8 @@ def isPkgInstalled(pkg, prefix='/', sortByVersion=False):
         else:
             return res
     else:
-        return filter(lambda x: filter(lambda y: y['PN'] == pkg,
-                                       map(reVerSplitToPV,
-                                           listDirectory(x))),
-                      listDirectory(pkgDir, fullPath=True))
+        return [x for x in listDirectory(pkgDir, fullPath=True) 
+            if [y for y in map(reVerSplitToPV,listDirectory(x)) if y['PN'] == pkg]]
 
 
 def getPkgSlot(pkg, prefix='/'):
@@ -225,7 +221,7 @@ def getSquashList():
         return list(set(usesSquashFs) & wantMethod)
 
 
-class RepositorySubstituting(object):
+class RepositorySubstituting():
     """
     Объект выполняющий подставнку repository:path пути
 
@@ -248,7 +244,7 @@ class RepositorySubstituting(object):
         # TODO: проверка выхода за chroot
         emerge_config = self.dv.Get('cl_emerge_config')
         if emerge_config and emerge_config.repositories:
-            repos = {x.name.encode('utf-8'): x.location.encode('utf-8')
+            repos = {x.name: x.location
                      for x in emerge_config.repositories}
             r = re.compile("|".join("^%s:" % x for x in repos.keys()))
             self._substitution = (
@@ -286,7 +282,7 @@ def searchProfile(dirpath, configname, repository_sub=None):
     return list(search(dirpath))
 
 
-class ReposConf(object):
+class ReposConf():
     def __init__(self, conffile, confdir, prefix="/"):
         self.conffile = conffile
         self.prefix = prefix
@@ -311,7 +307,7 @@ class ReposConf(object):
                      'location': rpath}.items():
             config.set(rname, k, v)
         self.add_default(config)
-        with open(conffile, 'wb') as f:
+        with open(conffile, 'w') as f:
             config.write(f)
 
     def remove(self, rname):
@@ -319,11 +315,11 @@ class ReposConf(object):
             return
         conffile = pathJoin(self.prefix, self.conffile)
         config = ConfigParser(strict=False)
-        config.read(conffile, encoding="utf-8")
+        config.read(conffile)
         if config.has_section(rname):
             config.remove_section(rname)
             self.add_default(config)
-            with open(conffile, 'wb') as f:
+            with open(conffile, 'w') as f:
                 config.write(f)
 
     def get_calculate_repositories(self):
@@ -332,7 +328,7 @@ class ReposConf(object):
         """
         conffile = pathJoin(self.prefix, self.conffile)
         config = ConfigParser(strict=False)
-        config.read(conffile, encoding="utf-8")
+        config.read(conffile)
         for rep in config.sections():
             if rep != "gentoo":
                 location = config[rep]["location"]
@@ -351,7 +347,7 @@ class ReposConf(object):
             if conffile == conffn:
                 continue
             config = ConfigParser(strict=False)
-            config.read(conffile, encoding="utf-8")
+            config.read(conffile)
             for rep in config.sections():
                 if rep not in skip_reps:
                     location = config[rep].get("location")
@@ -360,7 +356,7 @@ class ReposConf(object):
                         yield rep, location
 
 
-class Layman(object):
+class Layman():
     """
     Объект для управления репозиториями Layman
 
@@ -411,7 +407,7 @@ class Layman(object):
         """
         if path.exists(self.installed) and readFile(self.installed).strip():
             tree = ET.parse(self.installed)
-            root = tree.getroot()
+            root = tree.getroottree().getroot()
             # если репозиторий уже присутсвует в installed.xml
             if root.find("repo[name='%s']" % rname) is not None:
                 return
@@ -488,9 +484,9 @@ class Layman(object):
 
     def is_new_layman(self):
         layman_pkg_info = isPkgInstalled(self.layman_package,
-                                         prefix=self.prefix.encode('utf-8'))
+                                         prefix=self.prefix)
         portage_pkg_info = isPkgInstalled(self.portage_package,
-                                          prefix=self.prefix.encode('utf-8'))
+                                          prefix=self.prefix)
         if layman_pkg_info and portage_pkg_info:
             layman_ver = layman_pkg_info[0].get('PV')
             portage_ver = portage_pkg_info[0].get('PV')
@@ -515,7 +511,7 @@ class Layman(object):
         """
         if path.exists(self.installed) and readFile(self.installed).strip():
             tree = ET.parse(self.installed)
-            root = tree.getroot()
+            root = tree.getroottree().getroottree().getroottree().getroottree().getroottree().getroottree().getroot()
             el = root.find("repo[name='%s']" % rname)
             if el is not None:
                 root.remove(el)
@@ -694,9 +690,9 @@ class PackageInformation:
                                    timeout=60).read()
         except pexpect.TIMEOUT:
             output = ""
-        re_cut = re.compile("^.*?(?=<\?xml version)", re.S)
+        re_cut = re.compile(b"^.*?(?=<\?xml version)", re.S)
         with ignore(ET.ParseError):
-            xml = ET.fromstring(re_cut.sub('', output))
+            xml = ET.fromstring(re_cut.sub(b'', output))
             for pkg in self.query_packages:
                 cat_pn = pkg['CATEGORY/PN']
                 if not cat_pn in self.information_cache:
@@ -722,7 +718,7 @@ class UnmergePackage(EmergePackage):
     re_pkg_info = re.compile("^\s(\S+)\n\s+selected:\s(\S+)", re.MULTILINE)
 
     def __init__(self, package):
-        super(UnmergePackage, self).__init__(package)
+        super().__init__(package)
         if not isinstance(package, EmergePackage):
             self._package = self.convert_package_info(package)
 
@@ -834,7 +830,7 @@ class EmergeRemoveInfo(EmergeUpdateInfo):
     install_info = "\[(uninstall)([^\]]+)\]"
 
 
-class Eix(object):
+class Eix():
     """
     Вызов eix
 
@@ -844,7 +840,7 @@ class Eix(object):
     """
     cmd = getProgPath("/usr/bin/eix")
 
-    class Option(object):
+    class Option():
         Installed = '--installed'
         Xml = '--xml'
         Upgrade = '--upgrade'
@@ -889,7 +885,7 @@ class Eix(object):
         return list(self.parser.parseXml(self.get_output()))
 
 
-class EixParser(object):
+class EixParser():
     """
     Парсер XML вывода от eix
     """
@@ -933,17 +929,16 @@ class EixFullnameParserBestVersion(EixFullnameParser):
     """
     def get_versions(self, et):
         ret = None
-        for ver in ifilter(lambda x: x.find('mask') is None,
-                           et.iterfind('version')):
+        for ver in (x for x in et.iterfind('version') if x.find('mask') is None):
             ret = ver.attrib['id']
         yield ret
 
 
-class PackageVersionInfo(object):
+class PackageVersionInfo():
     """
     Информация о версии пакета
     """
-    class Mask(object):
+    class Mask():
         Keyword = 1
         MissingKeyword = 2
         Hardmask = 3
@@ -1044,14 +1039,14 @@ class ChrootEix(Eix):
         self.chroot_cmd = getProgPath("/usr/bin/chroot")
         self.chroot_path = chroot_path
         self.cmd = getProgPath("/usr/bin/eix", prefix=chroot_path)
-        super(ChrootEix, self).__init__(package, *options, **kwargs)
+        super().__init__(package, *options, **kwargs)
 
     def _process(self):
         return process(self.chroot_cmd, *([self.chroot_path, self.cmd]
                                           + self.options))
 
 
-class EmergeLogTask(object):
+class EmergeLogTask():
     def has_marker(self, line):
         """
         Определить есть ли в строке маркер задачи
@@ -1105,7 +1100,7 @@ class EmergeLogPackageTask(EmergeLogTask):
         """
         return ") Merging " in line
 
-class EmergeLog(object):
+class EmergeLog():
     """
     EmergeLog(after).get_update(package_pattern)
     """
@@ -1127,7 +1122,7 @@ class EmergeLog(object):
         """
         Получить список измений по логу, от последней записи маркера
         """
-        log_data = SavableIterator(iter(readLinesFile(self.emerge_log)))
+        log_data = SaveableIterator(iter(readLinesFile(self.emerge_log)))
         for line in log_data.save():
             if self.emerge_task.has_marker(line):
                 log_data.save()
@@ -1193,7 +1188,7 @@ class EmergeLogFiltered(EmergeLog):
     """
     Возвращает только список пакетов установленных указанным образом
     """
-    class EmergeType(object):
+    class EmergeType():
         Source = "source"
         Binary = "binary"
 
@@ -1224,7 +1219,7 @@ class EmergeLogFiltered(EmergeLog):
                 self._remove_list.append(m.group(2))
 
 
-class PackageList(object):
+class PackageList():
     """
     Список пакетов с возможностью среза и сравнением с версией
     """
@@ -1235,10 +1230,7 @@ class PackageList(object):
 
     def _packages(self):
         if self.result is None:
-            self.result = filter(lambda x: x['PN'],
-                                 imap(lambda x: (x if isinstance(x, Mapping)
-                                                 else EmergePackage(x)),
-                                      self._raw_list))
+            self.result = [x for x in [(y if isinstance(y, Mapping) else EmergePackage(y)) for y in self._raw_list] if x['PN']]
         return self.result
 
     def __getitem__(self, item):
@@ -1285,10 +1277,7 @@ class Manifest:
         """
         Получить список файлов из Manifest
         """
-        return imap(lambda x: x.group(1),
-                    ifilter(None,
-                            imap(self.re_dist.search,
-                                 readLinesFile(self._manifest))))
+        return [x.group(1) for x in map(self.re_dist.search, readLinesFile(self._manifest)) if x]
 
 
 class Ebuild:
@@ -1341,10 +1330,9 @@ def get_remove_list(directory, filelist, depth=1):
     """
     directory = path.normpath(directory)
     l = len(directory) + 1
-    for fn in ifilter(lambda x: not x[l:] in filelist,
-                      find(directory,
-                           onefilesystem=True,
-                           fullpath=True, depth=depth)):
+    for fn in (x for x 
+            in find(directory,onefilesystem=True,fullpath=True, depth=depth) 
+            if not x[l:] in filelist):
         if path.isfile(fn):
             yield fn
 
@@ -1376,7 +1364,7 @@ class SimpleRepositoryMapper(Mapping):
 class EbuildInfoError(Exception):
     pass
 
-class EbuildInfo(object):
+class EbuildInfo():
     """
     Информация о ebuild (DEPEND) из metadata
     """
@@ -1418,7 +1406,7 @@ class InstalledPackageInfoError(Exception):
     pass
 
 
-class InstalledPackageInfo(object):
+class InstalledPackageInfo():
     """
     Информация об установленном пакете (DEPEND) из /var/db/pkg
     """
@@ -1646,7 +1634,7 @@ def unhide_packages(prefix='/', force=False):
 XPAK_TMP = "/dev/shm/xpak"
 
 
-class tbz2(object):
+class tbz2():
     """
     Python3 portage.xpak.tbz2 simple wrapper
     """
@@ -1678,7 +1666,7 @@ class tbz2(object):
             raise PackageError(_("Failed to compose %s") % self.tbzfile)
 
 
-class BinaryPackage(object):
+class BinaryPackage():
     """
     Объект для модификации var/db файлов бинарного пакета
     """
@@ -1706,7 +1694,7 @@ class BinaryPackage(object):
     def clear(self):
         removeDir(self.work_dn)
 
-class WorldPackage(object):
+class WorldPackage():
     def __init__(self, package):
         self.pkg = EmergePackage(package)
 
@@ -1724,8 +1712,8 @@ class WorldPackage(object):
         return str("%s:%s"%(self.pkg["CATEGORY/PN"], self.pkg["SLOT"])
                    if self.pkg["SLOT!"] else self.pkg["CATEGORY/PN"])
 
-class WorldFile(object):
-    class DiffType(object):
+class WorldFile():
+    class DiffType():
         Added = 0
         Removed = 1
         Omitted = 2
@@ -1791,7 +1779,7 @@ def clear_binhost_garbage(dn):
         if fn.endswith(".portage.lockfile") or fn.endswith(".partial"):
             os.unlink(fn)
 
-class PortageState(object):
+class PortageState():
     """
     Подсчёт контрольной суммы для определения изменений /etc/portage
     """
@@ -1823,5 +1811,5 @@ class PortageState(object):
         for dn in self.paths:
             fdn = pathJoin(self.prefix, dn)
             for data in self.getpathdata(fdn):
-                m.update(data)
+                m.update(data.encode("UTF-8"))
         return m.hexdigest()
