@@ -14,13 +14,12 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import types
-from calculate.lib import cl_overriding
+from .. import cl_overriding
 import re
 import sys
 from itertools import *
 
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_lang import setLocalTranslate
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
@@ -29,7 +28,7 @@ setLocalTranslate('cl_lib3', sys.modules[__name__])
 _u = lambda t: t if isinstance(t, str) else t
 _uu = lambda *tt: tuple(_u(t) for t in tt)
 # _u8 = lambda t: t.encode('UTF-8', 'replace') if isinstance(t, str) else t
-_u8 = lambda t: t  if isinstance(t, str) else t
+_u8 = lambda t: t
 _uu8 = lambda *tt: tuple(_u8(t) for t in tt)
 
 
@@ -48,11 +47,11 @@ def columnMatrix(*cols):
             else:
                 yield part
 
-    return izip_longest(
+    return list(zip_longest(
         *starmap(splitter,
-                 izip_longest(islice(cols, 0, None, 2),
+                 zip_longest(islice(cols, 0, None, 2),
                               islice(cols, 1, None, 2))),
-        fillvalue="")
+        fillvalue=""))
 
 
 def columnStr(*cols):
@@ -70,8 +69,7 @@ def columnStr(*cols):
 
     def generateStrings(*cols):
         colWidth = list(islice(cols, 1, None, 2))
-        for line in map(lambda x: izip_longest(colWidth, x),
-                        columnMatrix(*cols)):
+        for line in (zip_longest(colWidth, x) for x in columnMatrix(*cols)):
             yield " ".join(("{0:%d}" % (width or 1)).format(s) for \
                            width, s in line)
 
@@ -114,7 +112,7 @@ def justify(s, width):
     return s.encode('utf-8')
 
 
-class tableReport(object):
+class tableReport():
     """Display data in table"""
 
     def __init__(self, title, headerList, dataList, colSpan=1):
@@ -124,9 +122,9 @@ class tableReport(object):
         # elements list for first table row
         self.headerList = headerList
         # row list (each row is list)
-        self.dataList = map(lambda x: map(lambda y: str(y).expandtabs(),
-                                          map(lambda y: y or "", x)),
-                            dataList)
+ 
+        self.dataList = [[str(y).expandtabs() for y 
+            in [z or "" for z in x]] for x in dataList]                
         # calculate columns list
         self.columnsWidth = self.getColumsnWidth()
         self.vertChar = colSpan * " " + "|" + colSpan * " "
@@ -145,13 +143,11 @@ class tableReport(object):
         spanSize = self.colSpan * 2 + 1
         if colNum < 0:
             colNum += len(self.columnsWidth)
-        currentSize = sum(map(lambda x: x + spanSize, self.columnsWidth)) + 1
+        currentSize = sum((x + spanSize for x in self.columnsWidth)) + 1
         if currentSize < maxSize and not forceMax:
             return
-        excludeSize = sum(map(lambda x: x[1] + spanSize,
-                              filter(lambda x: x[0] != colNum,
-                                     enumerate(
-                                         self.columnsWidth)))) + spanSize + 1
+        excludeSize = sum((x[1] + spanSize for x 
+            in enumerate(self.columnsWidth) if x[0] != colNum)) + spanSize + 1
         if maxSize - excludeSize > 5:
             self.columnsWidth[colNum] = maxSize - excludeSize
 
@@ -185,9 +181,8 @@ class tableReport(object):
 
     def createFormatStr(self, listStr, offset=0):
         """Создает список (текст, ширина ...)"""
-        return chain(*izip_longest(listStr,
-                                   map(lambda x:x-offset, self.columnsWidth),
-                                   fillvalue=""))
+        return chain(*zip_longest(listStr,
+         [x-offset for x in self.columnsWidth], fillvalue=""))
 
     def printFunc(self, s):
         """
@@ -239,7 +234,7 @@ class tableReport(object):
         for char, _print, row in printData:
             for line in row:
                 self.line_printer(char[self.colSpan:])
-                for i, width, txt in izip(count(),
+                for i, width, txt in zip(count(),
                                           self.columnsWidth, line):
                     if _print == self.body_printer:
                         align = "<"
@@ -268,10 +263,9 @@ class MultiReplace:
 
     def __init__(self, repl_dict):
         # string to string mapping; use a regular expression
-        keys = repl_dict.keys()
-        keys = list(keys)
+        keys = list(repl_dict.keys())
         keys.sort(reverse=True)  # lexical order
-        pattern = u"|".join([re.escape(key) for key in keys])
+        pattern = "|".join([re.escape(key) for key in keys])
         self.pattern = re.compile(pattern)
         self.dict = repl_dict
 
@@ -390,12 +384,8 @@ def convertStrListDict(val):
 
 def formatListOr(lst):
     """Convert list to string like this: [1,2,3] -> 1,2 or 3"""
-    lststr = map(lambda x: str(x), lst)
-    return (" %s " % _("or")).join(filter(lambda x: x,
-                                          [", ".join(map(lambda x: x or "''",
-                                                         lststr[:-1])),
-                                           "".join(lststr[-1:])]))
-
+    lststr = [str(x) for x in lst]
+    return (" %s " % _("or")).join((x for x in [", ".join((y or "''" for y in lststr[:-1])),"".join(lststr[-1:])] if x))
 
 def get_term_size(fd=sys.stdout.fileno()):
     """
@@ -428,14 +418,13 @@ def simplify_profiles(profiles, drop_words=("amd64", "x86")):
     """
     if len(profiles) < 2:
         if len(profiles) == 1:
-            return ["/".join(filter(lambda x: x not in drop_words,
-                                    profiles[0].split('/')))]
+            return ["/".join((x for x in profiles[0].split('/') if x not in drop_words))]
         return profiles
     matrix = [x.split('/') for x in profiles]
     # удаляем одинаковые начальные и конечные поля
     matrix = zip(*reversed(list(dropwhile(lambda x: x.count(x[0]) == len(x),
                                           (reversed(list(dropwhile(
                                               lambda x: x.count(x[0]) == len(x),
-                                              izip_longest(*matrix,
+                                              zip_longest(*matrix,
                                                            fillvalue="")))))))))
-    return ["/".join(filter(None, x)) for x in matrix]
+    return ["/".join((y for y in x if y)) for x in matrix]
