@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
+
 from itertools import tee
 from functools import total_ordering, wraps
 import warnings
@@ -38,7 +38,7 @@ except ImportError:
     json_module = None
 
 
-class SavableIterator:
+class SaveableIterator:
     """
     Итератор с возможность сохранять и восстанавливать состояние
     """
@@ -62,6 +62,8 @@ class SavableIterator:
     def next(self):
         return next(self.seq)
 
+    def __next__(self):
+        return next(self.seq)
 
 @contextmanager
 def ignore(exception):
@@ -93,6 +95,9 @@ class FalseObject(object):
     def __nonzero__(self):
         return False
 
+    def __bool__(self):
+        return False
+
     __gt__ = __ge__ = __le__ = __eq__ = __ne__ = __lt__
 
 
@@ -559,11 +564,10 @@ def firstelement(i, fallback=''):
         return x
     return fallback
 
-class GenericFs(object):
+class GenericFs(metaclass=ABCMeta):
     """
     Объект обобщения файловых систем
     """
-    __metaclass__ = ABCMeta
 
     @abstractmethod
     def exists(self, fn):
